"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeHighlights = exports.showHighlights = void 0;
const conversions_1 = require("../utils/conversions");
const states = new WeakMap();
/**
 * Show document highlights in the editor.
 * @param editor
 * @param highlights
 */
exports.showHighlights = (editor, highlights) => {
    const state = states.get(editor) || { marks: [] };
    for (const { kind, range } of highlights) {
        // TODO Use kind to style differently
        const [start, end] = conversions_1.cmRange(range);
        state.marks.push(editor.markText(start, end, {
            className: `cmw-highlight`,
        }));
    }
    states.set(editor, state);
};
/**
 * Remove document highlights from the editor.
 * @param editor
 */
exports.removeHighlights = (editor) => {
    const state = states.get(editor);
    if (!state)
        return;
    if (state.marks && state.marks.length > 0) {
        for (const mark of state.marks)
            mark.clear();
        state.marks.length = 0;
    }
    states.delete(editor);
};
//# sourceMappingURL=document-highlight.js.map