"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enableHoverInfo = exports.disableHoverInfo = exports.hoverInfoEnabled = exports.removeHoverInfo = exports.showHoverInfo = void 0;
const tooltip_1 = require("../ui/tooltip");
const conversions_1 = require("../utils/conversions");
const states = new WeakMap();
/**
 * Show hover information.
 * @param editor
 * @param pos Position of the event
 * @param hover
 * @param renderMarkdown
 */
exports.showHoverInfo = (editor, pos, hover, renderMarkdown = (x) => x) => {
    exports.removeHoverInfo(editor);
    if (Array.isArray(hover.contents) && hover.contents.length === 0)
        return;
    const info = conversions_1.hoverContentsToString(hover.contents, renderMarkdown);
    if (!info)
        return;
    const state = states.get(editor) || {};
    let start = pos;
    if (hover.range) {
        let end = pos;
        [start, end] = conversions_1.cmRange(hover.range);
        state.marker = editor.markText(start, end, {
            css: "text-decoration: underline",
        });
    }
    const el = document.createElement("div");
    el.innerHTML = info;
    const coords = editor.charCoords(start, "page");
    state.tooltip = tooltip_1.addTooltip(el, coords.left, coords.top);
    states.set(editor, state);
};
/**
 * Remove hover information from the editor.
 * @param editor
 */
exports.removeHoverInfo = (editor) => {
    const state = states.get(editor);
    if (!state)
        return;
    if (state.marker)
        state.marker.clear();
    if (state.tooltip)
        state.tooltip.remove();
    states.delete(editor);
};
exports.hoverInfoEnabled = (editor) => { var _a; return !((_a = states.get(editor)) === null || _a === void 0 ? void 0 : _a.disabled); };
exports.disableHoverInfo = (editor) => {
    exports.removeHoverInfo(editor);
    states.set(editor, { disabled: true });
};
exports.enableHoverInfo = (editor) => {
    exports.removeHoverInfo(editor);
};
//# sourceMappingURL=hover.js.map